@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminGenericAgent.pm - admin generic agent interface
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
-# --
-# $Id: AdminGenericAgent.pm,v 1.108 2013/01/11 16:49:46 ub Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -26,9 +24,6 @@ use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.108 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -443,6 +438,19 @@ sub Run {
                         TicketID      => $TicketID,
                         DynamicFields => 0,
                     );
+
+                    if ( !%Data ) {
+
+                        # get ticket data instead
+                        %Data = $Self->{TicketObject}->TicketGet(
+                            TicketID      => $TicketID,
+                            DynamicFields => 0,
+                        );
+
+                        # set missing information
+                        $Data{Subject} = $Data{Title};
+                    }
+
                     $Data{Age}
                         = $Self->{LayoutObject}->CustomerAge( Age => $Data{Age}, Space => ' ' );
                     $Data{css} = "PriorityID-$Data{PriorityID}";
