@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AgentTicketMove.pm - move tickets to queues
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: AgentTicketMove.pm,v 1.118 2012/11/20 14:49:47 mh Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -20,9 +18,6 @@ use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.118 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -123,8 +118,8 @@ sub Run {
                 Type => 'Small',
             );
             $Output .= $Self->{LayoutObject}->Warning(
-                Message => "Sorry, you need to be the ticket owner to perform this action.",
-                Comment => 'Please change the owner first.',
+                Message => $Self->{LayoutObject}->{LanguageObject}->Get('Sorry, you need to be the ticket owner to perform this action.'),
+                Comment => $Self->{LayoutObject}->{LanguageObject}->Get('Please change the owner first.'),
             );
 
             # show back link
