@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AgentTicketPhone.pm - to handle phone calls
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
-# --
-# $Id: AgentTicketPhone.pm,v 1.251 2013/01/30 00:00:42 cr Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -25,9 +23,6 @@ use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
 use Mail::Address;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.251 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -242,6 +237,20 @@ sub Run {
         my %CustomerData;
         my $ArticleFrom = '';
         if ( $GetParam{ArticleID} ) {
+
+            my $Access = $Self->{TicketObject}->TicketPermission(
+                Type     => 'ro',
+                TicketID => $Self->{TicketID},
+                UserID   => $Self->{UserID}
+            );
+
+            if ( !$Access ) {
+                return $Self->{LayoutObject}->NoPermission(
+                    Message    => "You need ro permission!",
+                    WithHeader => 'yes',
+                );
+            }
+
             %Article = $Self->{TicketObject}->ArticleGet(
                 ArticleID     => $GetParam{ArticleID},
                 DynamicFields => 0,
@@ -303,9 +312,12 @@ sub Run {
         # multiple addresses list
         # check email address
         my $CountFrom = scalar @MultipleCustomer || 1;
-        my %CustomerDataFrom = $Self->{CustomerUserObject}->CustomerUserDataGet(
-            User => $Article{CustomerUserID},
-        ) if $Article{CustomerUserID};
+        my %CustomerDataFrom;
+        if ( $Article{CustomerUserID} ) {
+            %CustomerDataFrom = $Self->{CustomerUserObject}->CustomerUserDataGet(
+                User => $Article{CustomerUserID},
+            );
+        }
 
         for my $Email ( Mail::Address->parse($ArticleFrom) ) {
 
@@ -333,8 +345,10 @@ sub Run {
                 $CountAux         = $CountFrom . 'Error';
             }
 
-            my $CustomerKey
-                = ( $CustomerDataFrom{UserEmail} eq $EmailAddress ? $Article{CustomerUserID} : '' );
+            my $CustomerKey = '';
+            if ( defined $CustomerDataFrom{UserEmail} && $CustomerDataFrom{UserEmail} eq $EmailAddress ) {
+                $CustomerKey = $Article{CustomerUserID};
+            }
 
             push @MultipleCustomer, {
                 Count            => $CountAux,
@@ -1244,6 +1258,18 @@ sub Run {
             && $Self->{Config}->{SplitLinkType}->{Direction}
             )
         {
+            my $Access = $Self->{TicketObject}->TicketPermission(
+                Type     => 'ro',
+                TicketID => $GetParam{LinkTicketID},
+                UserID   => $Self->{UserID}
+            );
+
+            if ( !$Access ) {
+                return $Self->{LayoutObject}->NoPermission(
+                    Message    => "You need ro permission!",
+                    WithHeader => 'yes',
+                );
+            }
 
             my $SourceKey = $GetParam{LinkTicketID};
             my $TargetKey = $TicketID;
