@@ -1,8 +1,6 @@
 # --
 # Kernel/System/CustomerCompany.pm - All customer company related function should be here eventually
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: CustomerCompany.pm,v 1.39 2012/12/03 10:37:10 jh Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,8 +15,7 @@ use warnings;
 use Kernel::System::Valid;
 use Kernel::System::Cache;
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.39 $) [1];
+use vars qw(@ISA);
 
 =head1 NAME
 
@@ -155,7 +152,7 @@ sub new {
         = $Self->{ConfigObject}->Get('CustomerCompany')->{Params}->{ForeignDB} ? 1 : 0;
 
     # see if database is case sensitive
-    $Self->{CaseInsensitive} = $Self->{DBObject}->GetDatabaseFunction('CaseInsensitive') || 0;
+    $Self->{CaseInsensitive} = $Self->{ConfigObject}->Get('CustomerCompany')->{Params}->{CaseSensitive} ? 0 : 1;
 
     if ( $Self->{ConfigObject}->Get('CustomerCompany')->{CacheTTL} ) {
         $Self->{CacheObject} = Kernel::System::Cache->new( %{$Self} );
@@ -652,9 +649,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.39 $ $Date: 2012/12/03 10:37:10 $
-
-=cut
