@@ -1,8 +1,6 @@
 # --
 # Kernel/System/CustomerUser/DB.pm - some customer user functions
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
-# --
-# $Id: DB.pm,v 1.112 2013/01/17 07:28:22 mb Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -21,8 +19,7 @@ use Kernel::System::CheckItem;
 use Kernel::System::Time;
 use Kernel::System::Valid;
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.112 $) [1];
+use vars qw(@ISA);
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -242,6 +239,7 @@ sub CustomerSearch {
             Value        => $Search,
             SearchPrefix => $Self->{SearchPrefix},
             SearchSuffix => $Self->{SearchSuffix},
+            CaseSensitive => $Self->{CaseSensitive},
         ) . ' ';
     }
     elsif ( $Param{PostMasterSearch} ) {
@@ -420,6 +418,7 @@ sub CustomerIDList {
             Value        => $SearchTermEscaped,
             SearchPrefix => $Self->{SearchPrefix},
             SearchSuffix => $Self->{SearchSuffix},
+            CaseSensitive => $Self->{CaseSensitive},
         );
         $SQL .= ' ';
     }
@@ -774,6 +773,22 @@ sub CustomerUserUpdate {
     # get old user data (pw)
     my %UserData = $Self->CustomerUserDataGet( User => $Param{ID} );
 
+    # if we update the email address, check if it already exists
+    if ( $Param{UserEmail} && $Self->{CustomerUserMap}->{CustomerUserEmailUniqCheck}
+         && lc $Param{UserEmail} ne lc $UserData{UserEmail} ) {
+        my %Result = $Self->CustomerSearch(
+            Valid            => 1,
+            PostMasterSearch => $Param{UserEmail},
+        );
+        if (%Result) {
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => 'Email already exists!',
+            );
+            return;
+        }
+    }
+
     # quote values
     my %Value;
     for my $Entry ( @{ $Self->{CustomerUserMap}->{Map} } ) {
