@@ -1,8 +1,6 @@
 # --
 # Kernel/System/DynamicField/Backend/Checkbox.pm - Delegate for DynamicField Checkbox backend
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: Checkbox.pm,v 1.62 2012/12/03 11:29:12 mg Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,9 +16,6 @@ use Kernel::System::VariableCheck qw(:all);
 use Kernel::System::DynamicFieldValue;
 use Kernel::System::DynamicField::Backend::BackendCommon;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.62 $) [1];
-
 =head1 NAME
 
 Kernel::System::DynamicField::Backend::Checkbox
@@ -206,14 +201,14 @@ sub EditFieldRender {
     if ( defined $FieldValue && IsHashRefWithData($FieldValue) ) {
         if (
             !defined $FieldValue->{FieldValue} &&
-            defined $FieldValue->{UsedValue} && $FieldValue->{UsedValue} eq '1'
+            defined $FieldValue->{UsedValue}   && $FieldValue->{UsedValue} eq '1'
             )
         {
             $Value = '0';
         }
         elsif (
             defined $FieldValue->{FieldValue} && $FieldValue->{FieldValue} eq '1' &&
-            defined $FieldValue->{UsedValue}  && $FieldValue->{UsedValue}  eq '1'
+            defined $FieldValue->{UsedValue} && $FieldValue->{UsedValue} eq '1'
             )
         {
             $Value = '1';
@@ -736,6 +731,9 @@ sub ObjectMatch {
 
     my $FieldName = 'DynamicField_' . $Param{DynamicFieldConfig}->{Name};
 
+    # return false if field is not defined
+    return 0 if ( !defined $Param{ObjectAttributes}->{$FieldName} );
+
     # return false if not match
     if ( $Param{ObjectAttributes}->{$FieldName} ne $Param{Value} ) {
         return 0;
@@ -796,9 +794,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.62 $ $Date: 2012/12/03 11:29:12 $
-
-=cut
