@@ -16,9 +16,6 @@ use Kernel::System::VariableCheck qw(:all);
 use Kernel::System::DynamicField::Backend;
 use Kernel::System::DynamicField;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.11 $) [1];
-
 =head1 NAME
 
 Kernel::System::ProcessManagement::Process - process lib
@@ -632,9 +629,13 @@ sub ProcessTransition {
             TicketObject => $Self->{TicketObject},
             );
         my $Success = $TransitionActionModuleObject->Run(
-            UserID => $Param{UserID},
-            Ticket => \%Data,
-            Config => $TransitionAction->{Config} || {},
+            UserID                   => $Param{UserID},
+            Ticket                   => \%Data,
+            ProcessEntityID          => $Param{ProcessEntityID},
+            ActivityEntityID         => $Param{ActivityEntityID},
+            TransitionEntityID       => $TransitionEntityID,
+            TransitionActionEntityID => $TransitionAction->{TransitionActionEntityID},
+            Config                   => $TransitionAction->{Config} || {},
         );
     }
 
@@ -853,9 +854,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.11 $ $Date: 2013-01-15 23:02:44 $
-
-=cut
